from setuptools import find_packages, setup

# PEP0440 compatible formatted version, see:
# https://www.python.org/dev/peps/pep-0440/
#
# release markers:
#   X.Y
#   X.Y.Z   # For bugfix releases
#
# pre-release markers:
#   X.YaN   # Alpha release
#   X.YbN   # Beta release
#   X.YrcN  # Release Candidate
#   X.Y     # Final release

# version.py defines the VERSION and VERSION_SHORT variables.
# We use exec here so we don't import allennlp whilst setting up.
VERSION = {}
with open("alnlp/version.py", "r") as version_file:
    exec(version_file.read(), VERSION)

setup(
    name="alnlp",
    version=VERSION["VERSION"],
    description="NLP metrics.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Intended Audience :: Science/Research",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    keywords="nlp metrics",
    url="https://github.com/allenai/allennlp",
    # The trademark for AllenAI should not be used
    # author="Allen Institute for Artificial Intelligence",
    # author_email="allennlp@allenai.org",
    license="Apache",
    packages=find_packages(
        include=['alnlp'],
        exclude=['allennlp', "*.tests", "*.tests.*", "tests.*", "tests", "test_fixtures", "test_fixtures.*"]
    ),
    install_requires=[
        "torch",
    ],
    include_package_data=False,
    python_requires=">=3.6",
    zip_safe=True,
)



"""
A `~nlpmetrics.metric.Metric` is some quantity or quantities
that can be accumulated during training or evaluation; for example,
accuracy or F1 score.
"""

from .attachment_scores import AttachmentScores
from .average import Average
from .boolean_accuracy import BooleanAccuracy
from .bleu import BLEU
from .rouge import ROUGE
from .categorical_accuracy import CategoricalAccuracy
from .covariance import Covariance
from .entropy import Entropy
from .evalb_bracketing_scorer import (
    EvalbBracketingScorer,
    DEFAULT_EVALB_DIR,
)
from .fbeta_measure import FBetaMeasure
from .f1_measure import F1Measure
from .mean_absolute_error import MeanAbsoluteError
from .metric import Metric
from .pearson_correlation import PearsonCorrelation
from .spearman_correlation import SpearmanCorrelation
from .perplexity import Perplexity
from .sequence_accuracy import SequenceAccuracy
from .span_based_f1_measure import SpanBasedF1Measure
from .unigram_recall import UnigramRecall
from .auc import Auc
